# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cardpay.model.plan_update_request_plan_data import (
    PlanUpdateRequestPlanData,
)  # noqa: F401,E501
from cardpay.model.request import Request  # noqa: F401,E501


class PlanUpdateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "request": "Request",
        "operation": "str",
        "plan_data": "PlanUpdateRequestPlanData",
    }

    attribute_map = {
        "request": "request",
        "operation": "operation",
        "plan_data": "plan_data",
    }

    def __init__(self, request=None, operation=None, plan_data=None):  # noqa: E501
        """PlanUpdateRequest - a model defined in Swagger"""  # noqa: E501

        self._request = None
        self._operation = None
        self._plan_data = None
        self.discriminator = None

        self.request = request
        self.operation = operation
        self.plan_data = plan_data

    @property
    def request(self):
        """Gets the request of this PlanUpdateRequest.  # noqa: E501

        Request  # noqa: E501

        :return: The request of this PlanUpdateRequest.  # noqa: E501
        :rtype: Request
        """
        return self._request

    @request.setter
    def request(self, request):
        """Sets the request of this PlanUpdateRequest.

        Request  # noqa: E501

        :param request: The request of this PlanUpdateRequest.  # noqa: E501
        :type: Request
        """
        if request is None:
            raise ValueError(
                "Invalid value for `request`, must not be `None`"
            )  # noqa: E501

        self._request = request

    class Operation(object):
        CHANGE_STATUS = "CHANGE_STATUS"
        RENAME = "RENAME"

    @property
    def operation(self):
        """Gets the operation of this PlanUpdateRequest.  # noqa: E501

        `CHANGE_STATUS` value to initiate operation for status changing. `RENAME` value to initiate operation for plan renaming.  # noqa: E501

        :return: The operation of this PlanUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._operation

    @operation.setter
    def operation(self, operation):
        """Sets the operation of this PlanUpdateRequest.

        `CHANGE_STATUS` value to initiate operation for status changing. `RENAME` value to initiate operation for plan renaming.  # noqa: E501

        :param operation: The operation of this PlanUpdateRequest.  # noqa: E501
        :type: str
        """
        if operation is None:
            raise ValueError(
                "Invalid value for `operation`, must not be `None`"
            )  # noqa: E501
        allowed_values = ["CHANGE_STATUS", "RENAME"]  # noqa: E501
        if operation not in allowed_values:
            raise ValueError(
                "Invalid value for `operation` ({0}), must be one of {1}".format(  # noqa: E501
                    operation, allowed_values
                )
            )

        self._operation = operation

    @property
    def plan_data(self):
        """Gets the plan_data of this PlanUpdateRequest.  # noqa: E501

        Plan data  # noqa: E501

        :return: The plan_data of this PlanUpdateRequest.  # noqa: E501
        :rtype: PlanUpdateRequestPlanData
        """
        return self._plan_data

    @plan_data.setter
    def plan_data(self, plan_data):
        """Sets the plan_data of this PlanUpdateRequest.

        Plan data  # noqa: E501

        :param plan_data: The plan_data of this PlanUpdateRequest.  # noqa: E501
        :type: PlanUpdateRequestPlanData
        """
        if plan_data is None:
            raise ValueError(
                "Invalid value for `plan_data`, must not be `None`"
            )  # noqa: E501

        self._plan_data = plan_data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(PlanUpdateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PlanUpdateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cardpay.model.payment_response import PaymentResponse  # noqa: F401,E501


class PaymentsList(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {"data": "list[PaymentResponse]", "has_more": "bool"}

    attribute_map = {"data": "data", "has_more": "has_more"}

    def __init__(self, data=None, has_more=None):  # noqa: E501
        """PaymentsList - a model defined in Swagger"""  # noqa: E501

        self._data = None
        self._has_more = None
        self.discriminator = None

        if data is not None:
            self.data = data
        if has_more is not None:
            self.has_more = has_more

    @property
    def data(self):
        """Gets the data of this PaymentsList.  # noqa: E501

        List of found objects  # noqa: E501

        :return: The data of this PaymentsList.  # noqa: E501
        :rtype: list[PaymentResponse]
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this PaymentsList.

        List of found objects  # noqa: E501

        :param data: The data of this PaymentsList.  # noqa: E501
        :type: list[PaymentResponse]
        """

        self._data = data

    @property
    def has_more(self):
        """Gets the has_more of this PaymentsList.  # noqa: E501

        Indicates if there are more elements for this period than were returned  # noqa: E501

        :return: The has_more of this PaymentsList.  # noqa: E501
        :rtype: bool
        """
        return self._has_more

    @has_more.setter
    def has_more(self, has_more):
        """Sets the has_more of this PaymentsList.

        Indicates if there are more elements for this period than were returned  # noqa: E501

        :param has_more: The has_more of this PaymentsList.  # noqa: E501
        :type: bool
        """

        self._has_more = has_more

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(PaymentsList, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PaymentsList):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ThreeDSecureData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "card_enrollment": "str",
        "cavv": "str",
        "cavv_algorithm": "str",
        "pa_res": "str",
        "status": "str",
        "three_d_secure_flow": "str",
        "xid": "str",
    }

    attribute_map = {
        "card_enrollment": "card_enrollment",
        "cavv": "cavv",
        "cavv_algorithm": "cavv_algorithm",
        "pa_res": "pa_res",
        "status": "status",
        "three_d_secure_flow": "three_d_secure_flow",
        "xid": "xid",
    }

    def __init__(
        self,
        card_enrollment=None,
        cavv=None,
        cavv_algorithm=None,
        pa_res=None,
        status=None,
        three_d_secure_flow=None,
        xid=None,
    ):  # noqa: E501
        """ThreeDSecureData - a model defined in Swagger"""  # noqa: E501

        self._card_enrollment = None
        self._cavv = None
        self._cavv_algorithm = None
        self._pa_res = None
        self._status = None
        self._three_d_secure_flow = None
        self._xid = None
        self.discriminator = None

        if card_enrollment is not None:
            self.card_enrollment = card_enrollment
        if cavv is not None:
            self.cavv = cavv
        if cavv_algorithm is not None:
            self.cavv_algorithm = cavv_algorithm
        if pa_res is not None:
            self.pa_res = pa_res
        if status is not None:
            self.status = status
        if three_d_secure_flow is not None:
            self.three_d_secure_flow = three_d_secure_flow
        if xid is not None:
            self.xid = xid

    @property
    def card_enrollment(self):
        """Gets the card_enrollment of this ThreeDSecureData.  # noqa: E501

        Card enrollment in 3DS flow, possible values are: S - 3D Secure Skipped, N - 3D Secure not enrolled, Y - 3D Secure enrolled  # noqa: E501

        :return: The card_enrollment of this ThreeDSecureData.  # noqa: E501
        :rtype: str
        """
        return self._card_enrollment

    @card_enrollment.setter
    def card_enrollment(self, card_enrollment):
        """Sets the card_enrollment of this ThreeDSecureData.

        Card enrollment in 3DS flow, possible values are: S - 3D Secure Skipped, N - 3D Secure not enrolled, Y - 3D Secure enrolled  # noqa: E501

        :param card_enrollment: The card_enrollment of this ThreeDSecureData.  # noqa: E501
        :type: str
        """
        if card_enrollment is not None and not re.search(
            r"[SNY]", card_enrollment
        ):  # noqa: E501
            raise ValueError(
                r"Invalid value for `card_enrollment`, must be a follow pattern or equal to `/[SNY]/`"
            )  # noqa: E501

        self._card_enrollment = card_enrollment

    @property
    def cavv(self):
        """Gets the cavv of this ThreeDSecureData.  # noqa: E501

        Cardholder authentication verification value  # noqa: E501

        :return: The cavv of this ThreeDSecureData.  # noqa: E501
        :rtype: str
        """
        return self._cavv

    @cavv.setter
    def cavv(self, cavv):
        """Sets the cavv of this ThreeDSecureData.

        Cardholder authentication verification value  # noqa: E501

        :param cavv: The cavv of this ThreeDSecureData.  # noqa: E501
        :type: str
        """

        self._cavv = cavv

    @property
    def cavv_algorithm(self):
        """Gets the cavv_algorithm of this ThreeDSecureData.  # noqa: E501

        CAVV algorithm  # noqa: E501

        :return: The cavv_algorithm of this ThreeDSecureData.  # noqa: E501
        :rtype: str
        """
        return self._cavv_algorithm

    @cavv_algorithm.setter
    def cavv_algorithm(self, cavv_algorithm):
        """Sets the cavv_algorithm of this ThreeDSecureData.

        CAVV algorithm  # noqa: E501

        :param cavv_algorithm: The cavv_algorithm of this ThreeDSecureData.  # noqa: E501
        :type: str
        """

        self._cavv_algorithm = cavv_algorithm

    @property
    def pa_res(self):
        """Gets the pa_res of this ThreeDSecureData.  # noqa: E501

        PaRes bank authentication result  # noqa: E501

        :return: The pa_res of this ThreeDSecureData.  # noqa: E501
        :rtype: str
        """
        return self._pa_res

    @pa_res.setter
    def pa_res(self, pa_res):
        """Sets the pa_res of this ThreeDSecureData.

        PaRes bank authentication result  # noqa: E501

        :param pa_res: The pa_res of this ThreeDSecureData.  # noqa: E501
        :type: str
        """

        self._pa_res = pa_res

    @property
    def status(self):
        """Gets the status of this ThreeDSecureData.  # noqa: E501

        3DS status (from PaRes for 3Ds 1.0, ARes message for 3Ds 2.0) (possible values Y,A,U)  # noqa: E501

        :return: The status of this ThreeDSecureData.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ThreeDSecureData.

        3DS status (from PaRes for 3Ds 1.0, ARes message for 3Ds 2.0) (possible values Y,A,U)  # noqa: E501

        :param status: The status of this ThreeDSecureData.  # noqa: E501
        :type: str
        """
        if status is not None and not re.search(r"[YAU]", status):  # noqa: E501
            raise ValueError(
                r"Invalid value for `status`, must be a follow pattern or equal to `/[YAU]/`"
            )  # noqa: E501

        self._status = status

    @property
    def three_d_secure_flow(self):
        """Gets the three_d_secure_flow of this ThreeDSecureData.  # noqa: E501

        Possible values: 3DS1 - 3DS 1.0 flow, 3DS2C - 3DS 2.0 challenge flow, 3DS2F - 3DS 2.0 frictionless flow  # noqa: E501

        :return: The three_d_secure_flow of this ThreeDSecureData.  # noqa: E501
        :rtype: str
        """
        return self._three_d_secure_flow

    @three_d_secure_flow.setter
    def three_d_secure_flow(self, three_d_secure_flow):
        """Sets the three_d_secure_flow of this ThreeDSecureData.

        Possible values: 3DS1 - 3DS 1.0 flow, 3DS2C - 3DS 2.0 challenge flow, 3DS2F - 3DS 2.0 frictionless flow  # noqa: E501

        :param three_d_secure_flow: The three_d_secure_flow of this ThreeDSecureData.  # noqa: E501
        :type: str
        """
        if three_d_secure_flow is not None and not re.search(
            r"3DS1|3DS2C|3DS2F", three_d_secure_flow
        ):  # noqa: E501
            raise ValueError(
                r"Invalid value for `three_d_secure_flow`, must be a follow pattern or equal to `/3DS1|3DS2C|3DS2F/`"
            )  # noqa: E501

        self._three_d_secure_flow = three_d_secure_flow

    @property
    def xid(self):
        """Gets the xid of this ThreeDSecureData.  # noqa: E501

        Transaction Id in PaRes  # noqa: E501

        :return: The xid of this ThreeDSecureData.  # noqa: E501
        :rtype: str
        """
        return self._xid

    @xid.setter
    def xid(self, xid):
        """Sets the xid of this ThreeDSecureData.

        Transaction Id in PaRes  # noqa: E501

        :param xid: The xid of this ThreeDSecureData.  # noqa: E501
        :type: str
        """

        self._xid = xid

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(ThreeDSecureData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ThreeDSecureData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class PaymentResponsePaymentData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "amount": "float",
        "arn": "str",
        "auth_code": "str",
        "created": "str",
        "currency": "str",
        "decline_code": "str",
        "decline_reason": "str",
        "id": "str",
        "invalid_data": "list[str]",
        "is_3d": "bool",
        "note": "str",
        "rrn": "str",
        "status": "str",
        "trans_type": "str",
    }

    attribute_map = {
        "amount": "amount",
        "arn": "arn",
        "auth_code": "auth_code",
        "created": "created",
        "currency": "currency",
        "decline_code": "decline_code",
        "decline_reason": "decline_reason",
        "id": "id",
        "invalid_data": "invalid_data",
        "is_3d": "is_3d",
        "note": "note",
        "rrn": "rrn",
        "status": "status",
        "trans_type": "trans_type",
    }

    def __init__(
        self,
        amount=None,
        arn=None,
        auth_code=None,
        created=None,
        currency=None,
        decline_code=None,
        decline_reason=None,
        id=None,
        invalid_data=None,
        is_3d=None,
        note=None,
        rrn=None,
        status=None,
        trans_type=None,
    ):  # noqa: E501
        """PaymentResponsePaymentData - a model defined in Swagger"""  # noqa: E501

        self._amount = None
        self._arn = None
        self._auth_code = None
        self._created = None
        self._currency = None
        self._decline_code = None
        self._decline_reason = None
        self._id = None
        self._invalid_data = None
        self._is_3d = None
        self._note = None
        self._rrn = None
        self._status = None
        self._trans_type = None
        self.discriminator = None

        if amount is not None:
            self.amount = amount
        if arn is not None:
            self.arn = arn
        if auth_code is not None:
            self.auth_code = auth_code
        if created is not None:
            self.created = created
        if currency is not None:
            self.currency = currency
        if decline_code is not None:
            self.decline_code = decline_code
        if decline_reason is not None:
            self.decline_reason = decline_reason
        if id is not None:
            self.id = id
        if invalid_data is not None:
            self.invalid_data = invalid_data
        if is_3d is not None:
            self.is_3d = is_3d
        if note is not None:
            self.note = note
        if rrn is not None:
            self.rrn = rrn
        if status is not None:
            self.status = status
        if trans_type is not None:
            self.trans_type = trans_type

    @property
    def amount(self):
        """Gets the amount of this PaymentResponsePaymentData.  # noqa: E501

        Payment amount  # noqa: E501

        :return: The amount of this PaymentResponsePaymentData.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this PaymentResponsePaymentData.

        Payment amount  # noqa: E501

        :param amount: The amount of this PaymentResponsePaymentData.  # noqa: E501
        :type: float
        """

        self._amount = amount

    @property
    def arn(self):
        """Gets the arn of this PaymentResponsePaymentData.  # noqa: E501

        ARN (Acquirer Reference Number), supplied by the acquiring financial institution, return only after receiving ARN from bank acquirer *(for BANKCARD payment method only)*  # noqa: E501

        :return: The arn of this PaymentResponsePaymentData.  # noqa: E501
        :rtype: str
        """
        return self._arn

    @arn.setter
    def arn(self, arn):
        """Sets the arn of this PaymentResponsePaymentData.

        ARN (Acquirer Reference Number), supplied by the acquiring financial institution, return only after receiving ARN from bank acquirer *(for BANKCARD payment method only)*  # noqa: E501

        :param arn: The arn of this PaymentResponsePaymentData.  # noqa: E501
        :type: str
        """

        self._arn = arn

    @property
    def auth_code(self):
        """Gets the auth_code of this PaymentResponsePaymentData.  # noqa: E501

        Authorization code, provided by bank *(for BANKCARD payment method only)*  # noqa: E501

        :return: The auth_code of this PaymentResponsePaymentData.  # noqa: E501
        :rtype: str
        """
        return self._auth_code

    @auth_code.setter
    def auth_code(self, auth_code):
        """Sets the auth_code of this PaymentResponsePaymentData.

        Authorization code, provided by bank *(for BANKCARD payment method only)*  # noqa: E501

        :param auth_code: The auth_code of this PaymentResponsePaymentData.  # noqa: E501
        :type: str
        """

        self._auth_code = auth_code

    @property
    def created(self):
        """Gets the created of this PaymentResponsePaymentData.  # noqa: E501

        Time when this payment started in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format (yyyy-MM-dd'T'HH:mm:ss'Z')  # noqa: E501

        :return: The created of this PaymentResponsePaymentData.  # noqa: E501
        :rtype: str
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this PaymentResponsePaymentData.

        Time when this payment started in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format (yyyy-MM-dd'T'HH:mm:ss'Z')  # noqa: E501

        :param created: The created of this PaymentResponsePaymentData.  # noqa: E501
        :type: str
        """

        self._created = created

    @property
    def currency(self):
        """Gets the currency of this PaymentResponsePaymentData.  # noqa: E501

        Payment currency code ([ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) code)  # noqa: E501

        :return: The currency of this PaymentResponsePaymentData.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this PaymentResponsePaymentData.

        Payment currency code ([ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) code)  # noqa: E501

        :param currency: The currency of this PaymentResponsePaymentData.  # noqa: E501
        :type: str
        """

        self._currency = currency

    @property
    def decline_code(self):
        """Gets the decline_code of this PaymentResponsePaymentData.  # noqa: E501

        Decline code (only in decline case)  # noqa: E501

        :return: The decline_code of this PaymentResponsePaymentData.  # noqa: E501
        :rtype: str
        """
        return self._decline_code

    @decline_code.setter
    def decline_code(self, decline_code):
        """Sets the decline_code of this PaymentResponsePaymentData.

        Decline code (only in decline case)  # noqa: E501

        :param decline_code: The decline_code of this PaymentResponsePaymentData.  # noqa: E501
        :type: str
        """

        self._decline_code = decline_code

    @property
    def decline_reason(self):
        """Gets the decline_reason of this PaymentResponsePaymentData.  # noqa: E501

        Bank's message about transaction decline reason (only in decline case)  # noqa: E501

        :return: The decline_reason of this PaymentResponsePaymentData.  # noqa: E501
        :rtype: str
        """
        return self._decline_reason

    @decline_reason.setter
    def decline_reason(self, decline_reason):
        """Sets the decline_reason of this PaymentResponsePaymentData.

        Bank's message about transaction decline reason (only in decline case)  # noqa: E501

        :param decline_reason: The decline_reason of this PaymentResponsePaymentData.  # noqa: E501
        :type: str
        """

        self._decline_reason = decline_reason

    @property
    def id(self):
        """Gets the id of this PaymentResponsePaymentData.  # noqa: E501

        CardPay's payment id  # noqa: E501

        :return: The id of this PaymentResponsePaymentData.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PaymentResponsePaymentData.

        CardPay's payment id  # noqa: E501

        :param id: The id of this PaymentResponsePaymentData.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def invalid_data(self):
        """Gets the invalid_data of this PaymentResponsePaymentData.  # noqa: E501

        Invalid card or billing data  # noqa: E501

        :return: The invalid_data of this PaymentResponsePaymentData.  # noqa: E501
        :rtype: list[str]
        """
        return self._invalid_data

    @invalid_data.setter
    def invalid_data(self, invalid_data):
        """Sets the invalid_data of this PaymentResponsePaymentData.

        Invalid card or billing data  # noqa: E501

        :param invalid_data: The invalid_data of this PaymentResponsePaymentData.  # noqa: E501
        :type: list[str]
        """

        self._invalid_data = invalid_data

    @property
    def is_3d(self):
        """Gets the is_3d of this PaymentResponsePaymentData.  # noqa: E501

        Was 3-D Secure authentication made or not *(for BANKCARD payment method only)*  # noqa: E501

        :return: The is_3d of this PaymentResponsePaymentData.  # noqa: E501
        :rtype: bool
        """
        return self._is_3d

    @is_3d.setter
    def is_3d(self, is_3d):
        """Sets the is_3d of this PaymentResponsePaymentData.

        Was 3-D Secure authentication made or not *(for BANKCARD payment method only)*  # noqa: E501

        :param is_3d: The is_3d of this PaymentResponsePaymentData.  # noqa: E501
        :type: bool
        """

        self._is_3d = is_3d

    @property
    def note(self):
        """Gets the note of this PaymentResponsePaymentData.  # noqa: E501

        Payment note  # noqa: E501

        :return: The note of this PaymentResponsePaymentData.  # noqa: E501
        :rtype: str
        """
        return self._note

    @note.setter
    def note(self, note):
        """Sets the note of this PaymentResponsePaymentData.

        Payment note  # noqa: E501

        :param note: The note of this PaymentResponsePaymentData.  # noqa: E501
        :type: str
        """

        self._note = note

    @property
    def rrn(self):
        """Gets the rrn of this PaymentResponsePaymentData.  # noqa: E501

        RRN (Retrieval Reference Number), supplied by the acquiring financial institution *(for BANKCARD payment method only)*  # noqa: E501

        :return: The rrn of this PaymentResponsePaymentData.  # noqa: E501
        :rtype: str
        """
        return self._rrn

    @rrn.setter
    def rrn(self, rrn):
        """Sets the rrn of this PaymentResponsePaymentData.

        RRN (Retrieval Reference Number), supplied by the acquiring financial institution *(for BANKCARD payment method only)*  # noqa: E501

        :param rrn: The rrn of this PaymentResponsePaymentData.  # noqa: E501
        :type: str
        """

        self._rrn = rrn

    class Status(object):
        NEW = "NEW"
        IN_PROGRESS = "IN_PROGRESS"
        DECLINED = "DECLINED"
        AUTHORIZED = "AUTHORIZED"
        COMPLETED = "COMPLETED"
        CANCELLED = "CANCELLED"
        REFUNDED = "REFUNDED"
        PARTIALLY_REFUNDED = "PARTIALLY_REFUNDED"
        VOIDED = "VOIDED"
        CHARGED_BACK = "CHARGED_BACK"
        CHARGEBACK_RESOLVED = "CHARGEBACK_RESOLVED"

    @property
    def status(self):
        """Gets the status of this PaymentResponsePaymentData.  # noqa: E501

        Current payment status, *(mandatory for WEBMONEY and BITCOIN payment method only)*  # noqa: E501

        :return: The status of this PaymentResponsePaymentData.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this PaymentResponsePaymentData.

        Current payment status, *(mandatory for WEBMONEY and BITCOIN payment method only)*  # noqa: E501

        :param status: The status of this PaymentResponsePaymentData.  # noqa: E501
        :type: str
        """
        allowed_values = [
            "NEW",
            "IN_PROGRESS",
            "DECLINED",
            "AUTHORIZED",
            "COMPLETED",
            "CANCELLED",
            "REFUNDED",
            "PARTIALLY_REFUNDED",
            "VOIDED",
            "CHARGED_BACK",
            "CHARGEBACK_RESOLVED",
        ]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}".format(  # noqa: E501
                    status, allowed_values
                )
            )

        self._status = status

    class TransType(object):
        _01 = "01"
        _03 = "03"
        _10 = "10"
        _11 = "11"
        _28 = "28"

    @property
    def trans_type(self):
        """Gets the trans_type of this PaymentResponsePaymentData.  # noqa: E501


        :return: The trans_type of this PaymentResponsePaymentData.  # noqa: E501
        :rtype: str
        """
        return self._trans_type

    @trans_type.setter
    def trans_type(self, trans_type):
        """Sets the trans_type of this PaymentResponsePaymentData.


        :param trans_type: The trans_type of this PaymentResponsePaymentData.  # noqa: E501
        :type: str
        """
        allowed_values = ["01", "03", "10", "11", "28"]  # noqa: E501
        if trans_type not in allowed_values:
            raise ValueError(
                "Invalid value for `trans_type` ({0}), must be one of {1}".format(  # noqa: E501
                    trans_type, allowed_values
                )
            )

        self._trans_type = trans_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(PaymentResponsePaymentData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PaymentResponsePaymentData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
